@@ -33,18 +33,14 @@ CountdownDockWidget *countdownWidget = nullptr;
 
 bool obs_module_load(void)
 {
-	const auto main_window =
-		static_cast<QMainWindow *>(obs_frontend_get_main_window());
+	const auto main_window = static_cast<QMainWindow *>(obs_frontend_get_main_window());
 	obs_frontend_push_ui_translation(obs_module_get_string);
 	countdownWidget = new CountdownDockWidget(main_window);
 
-	obs_frontend_add_dock_by_id("ashmanixCountdownWidget",
-				    obs_module_text("CountdownTimer"),
-				    countdownWidget);
+	obs_frontend_add_dock_by_id("ashmanixCountdownWidget", obs_module_text("CountdownTimer"), countdownWidget);
 	obs_frontend_pop_ui_translation();
 
-	blog(LOG_INFO, "plugin loaded successfully (version %s)",
-	     PLUGIN_VERSION);
+	obs_log(LOG_INFO, "plugin loaded successfully (version %s)", PLUGIN_VERSION);
 	return true;
 }
 
@@ -55,7 +51,7 @@ void obs_module_post_load(void)
 
 void obs_module_unload()
 {
-	blog(LOG_INFO, "plugin unloaded");
+	obs_log(LOG_INFO, "plugin unloaded");
 }
 
 const char *obs_module_name(void)
