@@ -132,39 +132,59 @@ void SettingsDialog::ConnectUISignalHandlers()
 	QObject::connect(ui->textSourceDropdownList, &QComboBox::currentTextChanged, this,
 			 &SettingsDialog::FormChangeDetected);
 
-	QObject::connect(ui->startOnStreamStartCheckBox, &QCheckBox::stateChanged, this,
-			 &SettingsDialog::FormChangeDetected);
-
-	QObject::connect(ui->switchSceneCheckBox, &QCheckBox::stateChanged, this,
-			 &SettingsDialog::SceneSwitchCheckBoxSelected);
-
 	QObject::connect(ui->sceneSourceDropdownList, &QComboBox::currentTextChanged, this,
 			 &SettingsDialog::FormChangeDetected);
 
-	QObject::connect(ui->endMessageCheckBox, &QCheckBox::stateChanged, this,
-			 &SettingsDialog::EndMessageCheckBoxSelected);
-
-	QObject::connect(ui->formatOutputCheckBox, &QCheckBox::stateChanged, this,
-			 &SettingsDialog::FormatOutputCheckBoxSelected);
-
 	QObject::connect(ui->formatOutputLineEdit, &QLineEdit::textChanged, this, &SettingsDialog::FormChangeDetected);
 
 	QObject::connect(ui->endMessageLineEdit, &QLineEdit::textChanged, this, &SettingsDialog::FormChangeDetected);
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+	QObject::connect(ui->startOnStreamStartCheckBox, &QCheckBox::checkStateChanged, this,
+			 &SettingsDialog::FormChangeDetected);
+	QObject::connect(ui->switchSceneCheckBox, &QCheckBox::checkStateChanged, this,
+			 &SettingsDialog::SceneSwitchCheckBoxSelected);
+	QObject::connect(ui->endMessageCheckBox, &QCheckBox::checkStateChanged, this,
+			 &SettingsDialog::EndMessageCheckBoxSelected);
+	QObject::connect(ui->formatOutputCheckBox, &QCheckBox::checkStateChanged, this,
+			 &SettingsDialog::FormatOutputCheckBoxSelected);
+	QObject::connect(ui->endMessageCheckBox, &QCheckBox::checkStateChanged, this,
+			 &SettingsDialog::EndMessageCheckBoxSelected);
+	QObject::connect(ui->formatOutputCheckBox, &QCheckBox::checkStateChanged, this,
+			 &SettingsDialog::FormatOutputCheckBoxSelected);
+
+	QObject::connect(ui->daysCheckBox, &QCheckBox::checkStateChanged, this, &SettingsDialog::FormChangeDetected);
+	QObject::connect(ui->hoursCheckBox, &QCheckBox::checkStateChanged, this, &SettingsDialog::FormChangeDetected);
+	QObject::connect(ui->minutesCheckBox, &QCheckBox::checkStateChanged, this, &SettingsDialog::FormChangeDetected);
+	QObject::connect(ui->secondsCheckBox, &QCheckBox::checkStateChanged, this, &SettingsDialog::FormChangeDetected);
+	QObject::connect(ui->leadZeroCheckBox, &QCheckBox::checkStateChanged, this,
+			 &SettingsDialog::FormChangeDetected);
+	QObject::connect(ui->countUpCheckBox, &QCheckBox::checkStateChanged, this, &SettingsDialog::FormChangeDetected);
+	QObject::connect(ui->smoothPeriodTimerCheckBox, &QCheckBox::checkStateChanged, this,
+			 &SettingsDialog::FormChangeDetected);
+#else
+	QObject::connect(ui->startOnStreamStartCheckBox, &QCheckBox::stateChanged, this,
+			 &SettingsDialog::FormChangeDetected);
+	QObject::connect(ui->switchSceneCheckBox, &QCheckBox::stateChanged, this,
+			 &SettingsDialog::SceneSwitchCheckBoxSelected);
+	QObject::connect(ui->endMessageCheckBox, &QCheckBox::stateChanged, this,
+			 &SettingsDialog::EndMessageCheckBoxSelected);
+	QObject::connect(ui->formatOutputCheckBox, &QCheckBox::stateChanged, this,
+			 &SettingsDialog::FormatOutputCheckBoxSelected);
+	QObject::connect(ui->endMessageCheckBox, &QCheckBox::stateChanged, this,
+			 &SettingsDialog::EndMessageCheckBoxSelected);
+	QObject::connect(ui->formatOutputCheckBox, &QCheckBox::stateChanged, this,
+			 &SettingsDialog::FormatOutputCheckBoxSelected);
+
 	QObject::connect(ui->daysCheckBox, &QCheckBox::stateChanged, this, &SettingsDialog::FormChangeDetected);
-
 	QObject::connect(ui->hoursCheckBox, &QCheckBox::stateChanged, this, &SettingsDialog::FormChangeDetected);
-
 	QObject::connect(ui->minutesCheckBox, &QCheckBox::stateChanged, this, &SettingsDialog::FormChangeDetected);
-
 	QObject::connect(ui->secondsCheckBox, &QCheckBox::stateChanged, this, &SettingsDialog::FormChangeDetected);
-
 	QObject::connect(ui->leadZeroCheckBox, &QCheckBox::stateChanged, this, &SettingsDialog::FormChangeDetected);
-
 	QObject::connect(ui->countUpCheckBox, &QCheckBox::stateChanged, this, &SettingsDialog::FormChangeDetected);
-
 	QObject::connect(ui->smoothPeriodTimerCheckBox, &QCheckBox::stateChanged, this,
 			 &SettingsDialog::FormChangeDetected);
+#endif
 
 	QObject::connect(ui->dialogButtonBox, &QDialogButtonBox::accepted, this, &SettingsDialog::OkButtonClicked);
 
@@ -403,6 +423,40 @@ void SettingsDialog::FormChangeDetected()
 	ui->dialogButtonBox->button(QDialogButtonBox::Apply)->setEnabled(true);
 }
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+
+void SettingsDialog::EndMessageCheckBoxSelected(Qt::CheckState state)
+{
+	if (state == Qt::CheckState::Checked) {
+		ui->endMessageLineEdit->setEnabled(true);
+	} else {
+		ui->endMessageLineEdit->setEnabled(false);
+	}
+	FormChangeDetected();
+}
+
+void SettingsDialog::SceneSwitchCheckBoxSelected(Qt::CheckState state)
+{
+	if (state == Qt::CheckState::Checked) {
+		ui->sceneSourceDropdownList->setEnabled(true);
+	} else {
+		ui->sceneSourceDropdownList->setEnabled(false);
+	}
+	FormChangeDetected();
+}
+
+void SettingsDialog::FormatOutputCheckBoxSelected(Qt::CheckState state)
+{
+	if (state == Qt::CheckState::Checked) {
+		ui->formatOutputLineEdit->setEnabled(true);
+	} else {
+		ui->formatOutputLineEdit->setEnabled(false);
+	}
+	FormChangeDetected();
+}
+
+#else
+
 void SettingsDialog::EndMessageCheckBoxSelected(int state)
 {
 	if (state) {
@@ -433,6 +487,8 @@ void SettingsDialog::FormatOutputCheckBoxSelected(int state)
 	FormChangeDetected();
 }
 
+#endif
+
 void SettingsDialog::ApplyButtonClicked()
 {
 	ApplyFormChanges();
